--- meta: title: Transition Tokens description: Transition tokens are used to provide consistent transitions throughout your app. --- # Transition Tokens Transition tokens are used to provide consistent transitions throughout your app. | Token | Value | Example | | --------------------------- | ------ | ------------------------------------------------------------------------------------------------ | | `--terra-transition-x-slow` | 1000ms |
| | `--terra-transition-slow` | 500ms |
| | `--terra-transition-medium` | 250ms |
| | `--terra-transition-fast` | 150ms |
| | `--terra-transition-x-fast` | 50ms |
|